***************
Release History
***************

.. Changelog entries should follow this format:

   version (release date)
   ======================

   **section**

   - One-line description of change (link to Github issue/PR)

.. Changes should be organized in one of several sections:

   - Added
   - Changed
   - Deprecated
   - Removed
   - Fixed

1.0.0 (August 8, 2019)
======================

Initial release of ``pytest-rng``!
Thanks to all of the contributors for making this possible!
